@@ -4,10 +4,10 @@
 # Copyright (c) Jupyter Development Team.
 # Distributed under the terms of the Modified BSD License.
 
-from tornado import web
+from tornado import web, gen
 
 from jupyter_server.base.handlers import JupyterHandler, path_regex
-from jupyter_server.utils import url_escape
+from jupyter_server.utils import url_escape, ensure_async
 from jupyter_server.extension.handler import (
     ExtensionHandlerMixin,
     ExtensionHandlerJinjaMixin
@@ -20,9 +20,11 @@ class EditorHandler(ExtensionHandlerJinjaMixin, ExtensionHandlerMixin, JupyterHa
     """Render the text editor interface."""
 
     @web.authenticated
+    @gen.coroutine
     def get(self, path):
         path = path.strip('/')
-        if not self.contents_manager.file_exists(path):
+        exists = yield ensure_async(self.contents_manager.file_exists(path))
+        if not exists:
             raise web.HTTPError(404, u'File does not exist: %s' % path)
 
         basename = path.rsplit('/', 1)[-1]
